==> aboki-0.2.tar.gz: aboki-0.2/README.md <==
# aboki

Black market currency rate instantly in your terminal! (Powered by
[AbokiFx](https://abokifx.com/).)

NOTE: I am in no way affiliated with AbokiFx. I don't know anyone that works there, have no relationship with them -- nothing.


## Prerequisites

Before using `aboki`, you should be familiar with foreign exchange and black market... *Duh!*


## Installation

You can install `aboki` via [pip](http://pip.readthedocs.org/en/latest/):

```bash
$ pip install aboki
```

Once `aboki` has been installed, you'll can start by running:

```bash
$ aboki test
```

## Usage

If you simply run `aboki` on the command line, you'll get a list of help.

```bash
$ aboki recent                          # show recent exchange rates
$ aboki rates <type>                    # show current exchange rates
$ aboki rate <currency>                 # show exchange rate for currency
$ aboki convert <amount> <FROM> <TO>    # see how much money you'll get if you sell
$ aboki test                            # test aboki
$ aboki (-h | --help)                   # display help information
```

All commands that have side effects will prompt you for action before doing anything for added security.

## Changelog

v0.2: 04-16-2017

    - Fixing some small documentation issues.

v0.1: 04-12-2017

    - First release!


## Like This?

If you've enjoyed using `aboki`, feel free to star this project, send me some bitcoin!  My address
is:

**17AcFdn8kTpGw1R34MC5U5SyZHrMbZK4Sq**

Or...  You could tip me on [paypal](https://www.paypal.me/akinjide) :)

<3

-Akinjide

==> aboki-0.3.tar.gz: aboki-0.3/README.md <==
# aboki

Black market currency rate instantly in your terminal! (Powered by
[AbokiFx](https://abokifx.com/).)

NOTE: I am in no way affiliated with AbokiFx. I don't know anyone that works there, have no relationship with them -- nothing.


## Prerequisites

Before using `aboki`, you should be familiar with foreign exchange and black market... *Duh!*


## Installation

You can install `aboki` via [pip](http://pip.readthedocs.org/en/latest/):

```bash
$ pip install aboki
```

Once `aboki` has been installed, you'll can start by running:

```bash
$ aboki test
```

## Usage

If you simply run `aboki` on the command line, you'll get a list of help.

```bash
$ aboki recent                          # show recent exchange rates
$ aboki rates <type>                    # show current exchange rates
$ aboki rate <currency>                 # show exchange rate for currency
$ aboki convert <amount> <FROM> <TO>    # see how much money you'll get if you sell
$ aboki test                            # test aboki
$ aboki (-h | --help)                   # display help information
```

All commands that have side effects will prompt you for action before doing anything for added security.

## Changelog

v0.3: 05-09-2017

    - Python 3 Support and Error handling.

v0.2: 04-16-2017

    - Fixing some small documentation issues.

v0.1: 04-12-2017

    - First release!


## Like This?

If you've enjoyed using `aboki`, feel free to star this project, send me some bitcoin!  My address is:

**17AcFdn8kTpGw1R34MC5U5SyZHrMbZK4Sq**

Or...  You could tip me on [paypal](https://www.paypal.me/akinjide) :)

<3

-Akinjide
